@@ -1,36 +1,37 @@
 from __future__ import annotations
 
-from typing import Optional, Union
 from datetime import datetime
+from typing import Optional, Union
 
 import disruptive
 import disruptive.logging as dtlog
 import disruptive.outputs as dtoutputs
 import disruptive.transforms as dttrans
 
-# Event-type constants.
-TOUCH = 'touch'
-TEMPERATURE = 'temperature'
-OBJECT_PRESENT = 'objectPresent'
-HUMIDITY = 'humidity'
-OBJECT_PRESENT_COUNT = 'objectPresentCount'
-TOUCH_COUNT = 'touchCount'
-WATER_PRESENT = 'waterPresent'
-NETWORK_STATUS = 'networkStatus'
-BATTERY_STATUS = 'batteryStatus'
-LABELS_CHANGED = 'labelsChanged'
-CONNECTION_STATUS = 'connectionStatus'
-ETHERNET_STATUS = 'ethernetStatus'
-CELLULAR_STATUS = 'cellularStatus'
-CO2 = 'co2'
-PRESSURE = 'pressure'
-MOTION = 'motion'
-DESK_OCCUPANCY = 'deskOccupancy'
+TOUCH: str = 'touch'
+TEMPERATURE: str = 'temperature'
+OBJECT_PRESENT: str = 'objectPresent'
+HUMIDITY: str = 'humidity'
+OBJECT_PRESENT_COUNT: str = 'objectPresentCount'
+TOUCH_COUNT: str = 'touchCount'
+WATER_PRESENT: str = 'waterPresent'
+NETWORK_STATUS: str = 'networkStatus'
+BATTERY_STATUS: str = 'batteryStatus'
+LABELS_CHANGED: str = 'labelsChanged'
+CONNECTION_STATUS: str = 'connectionStatus'
+ETHERNET_STATUS: str = 'ethernetStatus'
+CELLULAR_STATUS: str = 'cellularStatus'
+CO2: str = 'co2'
+PRESSURE: str = 'pressure'
+MOTION: str = 'motion'
+DESK_OCCUPANCY: str = 'deskOccupancy'
+CONTACT: str = 'contact'
+PROBE_WIRE_STATUS: str = 'probeWireStatus'
 EVENT_TYPES = [
     TOUCH, TEMPERATURE, OBJECT_PRESENT, HUMIDITY, OBJECT_PRESENT_COUNT,
     TOUCH_COUNT, WATER_PRESENT, NETWORK_STATUS, BATTERY_STATUS, LABELS_CHANGED,
     CONNECTION_STATUS, ETHERNET_STATUS, CELLULAR_STATUS, CO2, PRESSURE, MOTION,
-    DESK_OCCUPANCY,
+    DESK_OCCUPANCY, CONTACT, PROBE_WIRE_STATUS,
 ]
 
 
@@ -234,6 +235,8 @@ class Temperature(_EventData):
         Temperature value in Fahrenheit.
     samples : list[TemperatureSample]
         Temperature values sampled over a single heartbeat.
+    is_backfilled : bool
+        Indicates if the temperature event is backfilled.
     timestamp : datetime
         Timestamp of when the event was received by a Cloud Connector.
 
@@ -242,6 +245,7 @@ class Temperature(_EventData):
     def __init__(self,
                  celsius: float,
                  samples: Optional[list] = None,
+                 is_backfilled: Optional[bool] = None,
                  timestamp: Optional[datetime | str] = None,
                  ) -> None:
         """
@@ -254,6 +258,8 @@ class Temperature(_EventData):
             Temperature value in Celsius.
         samples : list[TemperatureSample]
             Temperature values sampled over a single heartbeat.
+        is_backfilled : bool
+            Indicates if the temperature event is backfilled.
         timestamp : datetime, str, optional
             Timestamp in either datetime or string iso8601 format
             (i.e. yyyy-MM-ddTHH:mm:ssZ).
@@ -264,6 +270,7 @@ class Temperature(_EventData):
         self.celsius: float = celsius
         self.samples: Optional[list] = samples
         self.fahrenheit: float = dttrans._celsius_to_fahrenheit(celsius)
+        self.is_backfilled: Optional[bool] = is_backfilled
         self.timestamp: Optional[datetime | str] = timestamp
 
         # Inherit parent _EventData class init with repacked data dictionary.
@@ -273,6 +280,7 @@ class Temperature(_EventData):
         string = '{}.{}('\
             'celsius={}, '\
             'samples={}, '\
+            'is_backfilled={}, '\
             'timestamp={}'\
             ')'
         return string.format(
@@ -280,6 +288,7 @@ class Temperature(_EventData):
             self.__class__.__name__,
             self.celsius,
             self.samples,
+            self.is_backfilled,
             repr(dttrans.to_iso8601(self.timestamp)),
         )
 
@@ -312,6 +321,7 @@ class Temperature(_EventData):
         obj = cls(
             celsius=data['value'],
             samples=sample_objs,
+            is_backfilled=data['isBackfilled'],
             timestamp=data['updateTime'],
         )
 
@@ -326,6 +336,8 @@ class Temperature(_EventData):
             data['value'] = self.celsius
         if self.samples is not None:
             data['samples'] = [s._raw for s in self.samples]
+        if self.is_backfilled is not None:
+            data['isBackfilled'] = self.is_backfilled
         if self.timestamp is not None:
             data['updateTime'] = self.timestamp
         return data
@@ -502,10 +514,13 @@ class Humidity(_EventData):
 
     Attributes
     ----------
-    temperature : float
+    celsius : float
         Temperature value in Celsius.
     relative_humidity : float
         Relative humidity in percent.
+    samples : list[HumiditySample]
+        Relative humidity and temperature values sampled over
+        a single heartbeat.
     timestamp : datetime
         Timestamp of when the event was received by a Cloud Connector.
 
@@ -514,6 +529,8 @@ class Humidity(_EventData):
     def __init__(self,
                  celsius: float,
                  relative_humidity: float,
+                 samples: Optional[list] = None,
+                 is_backfilled: Optional[bool] = None,
                  timestamp: Optional[datetime | str] = None,
                  ):
         """
@@ -521,10 +538,15 @@ class Humidity(_EventData):
 
         Parameters
         ----------
-        temperature : float
+        celsius : float
             Temperature value in Celsius.
         relative_humidity : float
             Relative humidity in percent.
+        samples : list[HumiditySample]
+            Relative humidity and temperature values sampled over
+            a single heartbeat.
+        is_backfilled : bool
+            Indicates if the humidity event is backfilled.
         timestamp : datetime, str, optional
             Timestamp in either datetime or string iso8601 format
             (i.e. yyyy-MM-ddTHH:mm:ssZ).
@@ -535,6 +557,8 @@ class Humidity(_EventData):
         self.celsius: float = celsius
         self.fahrenheit: float = dttrans._celsius_to_fahrenheit(celsius)
         self.relative_humidity: float = relative_humidity
+        self.samples: Optional[list] = samples
+        self.is_backfilled: Optional[bool] = is_backfilled
         self.timestamp: Optional[datetime | str] = timestamp
 
         # Inherit parent _EventData class init with repacked data dictionary.
@@ -544,6 +568,8 @@ class Humidity(_EventData):
         string = '{}.{}('\
             'celsius={}, '\
             'relative_humidity={}, '\
+            'samples={}, '\
+            'is_backfilled={}, '\
             'timestamp={}'\
             ')'
         return string.format(
@@ -551,6 +577,8 @@ class Humidity(_EventData):
             self.__class__.__name__,
             self.celsius,
             self.relative_humidity,
+            self.samples,
+            self.is_backfilled,
             repr(dttrans.to_iso8601(self.timestamp)),
         )
 
@@ -571,10 +599,21 @@ class Humidity(_EventData):
 
         """
 
+        # Convert samples dictionaries to HumiditySample objects.
+        sample_objs = []
+        for sample in data['samples']:
+            sample_objs.append(HumiditySample(
+                celsius=sample['temperature'],
+                relative_humidity=sample['relativeHumidity'],
+                timestamp=sample['sampleTime'],
+            ))
+
         # Construct the object with unpacked parameters.
         obj = cls(
             celsius=data['temperature'],
             relative_humidity=data['relativeHumidity'],
+            samples=sample_objs,
+            is_backfilled=data['isBackfilled'],
             timestamp=data['updateTime'],
         )
 
@@ -589,11 +628,99 @@ class Humidity(_EventData):
             data['temperature'] = self.celsius
         if self.relative_humidity is not None:
             data['relativeHumidity'] = self.relative_humidity
+        if self.is_backfilled is not None:
+            data['isBackfilled'] = self.is_backfilled
         if self.timestamp is not None:
             data['updateTime'] = self.timestamp
         return data
 
 
+class HumiditySample(dtoutputs.OutputBase):
+    """
+    Represents a single temperature event sample from a heartbeat period.
+
+    Attributes
+    ----------
+    celsius : float
+        Temperature value in Celsius.
+    fahrenheit : float
+        Temperature value in Fahrenheit.
+    relative_humidity : float
+        Relative humidity in percent.
+    timestamp : datetime
+        Interpolated inter-heartbeat timestamp.
+
+    """
+
+    def __init__(self,
+                 celsius: float,
+                 relative_humidity: float,
+                 timestamp: datetime | str,
+                 ) -> None:
+        """
+        Constructs the TemperatureSample object. The `fahrenheit` attribute is
+        calculated from the provided `celsius` parameter.
+
+        Parameters
+        ----------
+        celsius : float
+            Temperature value in Celsius.
+        relative_humidity : float
+            Relative humidity in percent.
+        timestamp : datetime, str, optional
+            Timestamp in either datetime or string iso8601 format
+            (i.e. yyyy-MM-ddTHH:mm:ssZ).
+
+        """
+
+        # Set parameter attributes.
+        self.celsius: float = celsius
+        self.fahrenheit: float = dttrans._celsius_to_fahrenheit(celsius)
+        self.relative_humidity: float = relative_humidity
+        self.timestamp = dttrans.to_datetime(timestamp)
+
+        # Inherit parent class.
+        dtoutputs.OutputBase.__init__(self, self.__repack())
+
+    def __repr__(self) -> str:
+        string = '{}.{}('\
+            'celsius={}, '\
+            'relative_humidity={}, '\
+            'timestamp={}'\
+            ')'
+        return string.format(
+            self.__class__.__module__,
+            self.__class__.__name__,
+            self.celsius,
+            self.relative_humidity,
+            repr(dttrans.to_iso8601(self.timestamp)),
+        )
+
+    @classmethod
+    def _from_raw(cls, data: dict) -> HumiditySample:
+        # Construct the object with unpacked parameters.
+        obj = cls(
+            celsius=data['temperature'],
+            relative_humidity=data['relativeHumidity'],
+            timestamp=data['sampleTime'],
+        )
+
+        # Inherit parent class.
+        dtoutputs.OutputBase.__init__(obj, data)
+
+        return obj
+
+    def __repack(self) -> dict:
+        data: dict = dict()
+        if self.celsius is not None:
+            data['celsius'] = self.celsius
+        if self.relative_humidity is not None:
+            data['relativeHumidity'] = self.relative_humidity
+        if self.timestamp is not None:
+            data['sampleTime'] = dttrans.to_iso8601(self.timestamp)
+        return data
+
+
 class ObjectPresentCount(_EventData):
     """
     Represents the data found in an objectPresentCount event.
@@ -1290,15 +1417,24 @@ class ConnectionStatus(_EventData):
     Attributes
     ----------
     connection : str
-        Whether the Cloud Connector is on "ETHERNET", "CELLULAR", or "OFFLINE".
+        Whether the current connection is
+        SDS, ETHERNET, CELLULAR, or OFFLINE.
     available : list[str]
-        Lists available connections. Can contain
-        "ETHERNET", "CELLULAR", or both.
+        A list of the string types of networks available to the device.
+        For Cloud Connectors, this can contain the values
+        ETHERNET, CELLULAR, or both. For Sensors, it will contain
+        only SDS when its online. This field will be empty when
+        the device's connection is OFFLINE.
     timestamp : datetime
         Timestamp of when the event was received by a Cloud Connector.
 
     """
 
+    CONNECTION_SDS: str = 'SDS'
+    CONNECTION_ETHERNET: str = 'ETHERNET'
+    CONNECTION_CELLULAR: str = 'CELLULAR'
+    CONNECTION_OFFLINE: str = 'OFFLINE'
+
     def __init__(self,
                  connection: str,
                  available: list[str],
@@ -1310,14 +1446,16 @@ class ConnectionStatus(_EventData):
         Parameters
         ----------
         connection : str
-            Whether the Cloud Connector is on
-            "ETHERNET", "CELLULAR", or "OFFLINE".
+            Whether the current connection is
+            SDS, ETHERNET, CELLULAR, or OFFLINE.
         available : list[str]
-            Lists available connections.
-            Can contain "ETHERNET", "CELLULAR", or both.
-        timestamp : datetime, str, optional
-            Timestamp in either datetime or string iso8601 format
-            (i.e. yyyy-MM-ddTHH:mm:ssZ).
+            A list of the string types of networks available to the device.
+            For Cloud Connectors, this can contain the values
+            ETHERNET, CELLULAR, or both. For Sensors, it will contain
+            only SDS when its online. This field will be empty when
+            the device's connection is OFFLINE.
+        timestamp : datetime
+            Timestamp of when the event was received by a Cloud Connector.
 
         """
 
@@ -1934,6 +2072,188 @@ class DeskOccupancy(_EventData):
         return data
 
 
+class Contact(_EventData):
+    """
+    Represents the data found in a contact event.
+
+    Attributes
+    ----------
+    state : str
+        Indicates whether the sensor detects "CLOSED" or "OPEN".
+    timestamp : datetime
+        Timestamp of when the event was received by a Cloud Connector.
+
+    """
+
+    STATE_CLOSED: str = 'CLOSED'
+    STATE_OPEN: str = 'OPEN'
+
+    def __init__(self,
+                 state: str,
+                 timestamp: Optional[datetime | str] = None,
+                 ) -> None:
+        """
+        Constructs the Contact object, inheriting parent class
+        and setting the type-specific attributes.
+
+        Parameters
+        ----------
+        state : str
+            Indicates whether the sensor predicts "CLOSED" or "OPEN".
+        timestamp : datetime, str, optional
+            Timestamp in either datetime or string ISO8601 format
+            (i.e. yyyy-MM-ddTHH:mm:ssZ).
+
+        """
+
+        self.state: str = state
+        self.timestamp: Optional[datetime | str] = timestamp
+
+        # Inherit parent _EventData class init with repacked data dictionary.
+        _EventData.__init__(self, self.__repack(), 'contact')
+
+    def __repr__(self) -> str:
+        string = '{}.{}('\
+            'state={}, '\
+            'timestamp={}, '\
+            ')'
+        return string.format(
+            self.__class__.__module__,
+            self.__class__.__name__,
+            repr(self.state),
+            repr(dttrans.to_iso8601(self.timestamp)),
+        )
+
+    @classmethod
+    def _from_raw(cls, data: dict) -> Contact:
+        """
+        Constructs a Contact object from API response data.
+
+        Parameters
+        ----------
+        data : dict
+            API response data dictionary.
+
+        Returns
+        -------
+        obj : Contact
+            Object constructed from the API response data.
+
+        """
+
+        # Construct the object with unpacked parameters.
+        obj = cls(
+            state=data['state'],
+            timestamp=data['updateTime'],
+        )
+
+        # Re-inherit from parent, but now providing response data.
+        _EventData.__init__(obj, data, obj.event_type)
+
+        return obj
+
+    def __repack(self) -> dict:
+        data: dict = dict()
+        if self.state is not None:
+            data['state'] = self.state
+        if self.timestamp is not None:
+            data['updateTime'] = self.timestamp
+        return data
+
+
+class ProbeWireStatus(_EventData):
+    """
+    Represents the data found in a contact event.
+
+    Attributes
+    ----------
+    timestamp : datetime
+        Timestamp of when the event was received by a Cloud Connector.
+
+    """
+
+    STATE_INVALID_WIRE_CONFIGURATION: str = 'INVALID_WIRE_CONFIGURATION'
+    STATE_INVALID_COEFFICIENT_CONFIGURATION: str \
+        = 'INVALID_COEFFICIENT_CONFIGURATION'
+    STATE_TWO_WIRE: str = 'TWO_WIRE'
+    STATE_THREE_WIRE: str = 'THREE_WIRE'
+    STATE_FOUR_WIRE: str = 'FOUR_WIRE'
+
+    def __init__(self,
+                 state: str,
+                 timestamp: Optional[datetime | str] = None,
+                 ) -> None:
+        """
+        Constructs the ProbeWireStatus object, inheriting parent class
+        and setting the type-specific attributes.
+
+        Parameters
+        ----------
+        state : str
+            Probe wire status. Can be either "INVALID_WIRE_CONFIGURATION",
+            "INVALID_COEFFICIENT_CONFIGURATION", "TWO_WIRE",
+            "THREE_WIRE", or "FOUR_WIRE".
+        timestamp : datetime, str, optional
+            Timestamp in either datetime or string ISO8601 format
+            (i.e. yyyy-MM-ddTHH:mm:ssZ).
+
+        """
+
+        self.state: str = state
+        self.timestamp: Optional[datetime | str] = timestamp
+
+        # Inherit parent _EventData class init with repacked data dictionary.
+        _EventData.__init__(self, self.__repack(), 'probeWireStatus')
+
+    def __repr__(self) -> str:
+        string = '{}.{}('\
+            'state={}, '\
+            'timestamp={}, '\
+            ')'
+        return string.format(
+            self.__class__.__module__,
+            self.__class__.__name__,
+            repr(self.state),
+            repr(dttrans.to_iso8601(self.timestamp)),
+        )
+
+    @classmethod
+    def _from_raw(cls, data: dict) -> ProbeWireStatus:
+        """
+        Constructs a ProbeWireStatus object from API response data.
+
+        Parameters
+        ----------
+        data : dict
+            API response data dictionary.
+
+        Returns
+        -------
+        obj : Contact
+            Object constructed from the API response data.
+
+        """
+
+        # Construct the object with unpacked parameters.
+        obj = cls(
+            state=data['state'],
+            timestamp=data['updateTime'],
+        )
+
+        # Re-inherit from parent, but now providing response data.
+        _EventData.__init__(obj, data, obj.event_type)
+
+        return obj
+
+    def __repack(self) -> dict:
+        data: dict = dict()
+        if self.state is not None:
+            data['state'] = self.state
+        if self.timestamp is not None:
+            data['updateTime'] = self.timestamp
+        return data
+
+
 class Event(dtoutputs.OutputBase):
     """
     Represents device events.
@@ -2123,6 +2443,18 @@ class __EventsMap():
             class_name='DeskOccupancy',
             is_keyed=True,
         ),
+        'contact': __TypeNames(
+            api_name='contact',
+            attr_name='contact',
+            class_name='Contact',
+            is_keyed=True,
+        ),
+        'probeWireStatus': __TypeNames(
+            api_name='probeWireStatus',
+            attr_name='probe_wire_status',
+            class_name='ProbeWireStatus',
+            is_keyed=True,
+        ),
     }
 
 
