@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, Optional, List, Tuple
+from typing import Any, Optional
 
 import disruptive.outputs as dtoutputs
 import disruptive.requests as dtrequests
@@ -44,7 +44,11 @@ class Claim(dtoutputs.OutputBase):
             self._resolve_type(claim)
 
     @classmethod
-    def claim_info(cls, identifier: str, **kwargs: Any) -> Claim:
+    def claim_info(cls,
+                   identifier: str,
+                   organization_id: Optional[str] = None,
+                   **kwargs: Any,
+                   ) -> Claim:
         """
         Get claim information for either a device
         or a kit by looking up an identifier.
@@ -63,6 +67,9 @@ class Claim(dtoutputs.OutputBase):
         ----------
         identifier : str
             Unique identifier of the target Kit or Device.
+        organization_id : str, optional
+            The identifier of the organization that will claim the
+            devices or kits.
 
         Returns
         -------
@@ -89,15 +96,19 @@ class Claim(dtoutputs.OutputBase):
 
         url = f'/claimInfo?identifier={identifier}'
 
+        # Add organization resource name to url if provided.
+        if organization_id is not None:
+            url += f'&organization=organizations/{organization_id}'
+
         return cls(dtrequests.DTRequest.get(url, **kwargs))
 
     @staticmethod
     def claim(target_project_id: str,
-              kit_ids: Optional[List[str]] = None,
-              device_ids: Optional[List[str]] = None,
+              kit_ids: Optional[list[str]] = None,
+              device_ids: Optional[list[str]] = None,
               dry_run: bool = True,
               **kwargs: Any,
-              ) -> Tuple[List[Claim.ClaimDevice], List[Exception]]:
+              ) -> tuple[list[Claim.ClaimDevice], list[Exception]]:
         """
         Claim multiple kits and/or devices to your project.
 
@@ -188,8 +199,8 @@ class Claim(dtoutputs.OutputBase):
         )
 
     @staticmethod
-    def _parse_claim_errors(res_errors: dict) -> List[Exception]:
-        errors: List[Exception] = []
+    def _parse_claim_errors(res_errors: dict) -> list[Exception]:
+        errors: list[Exception] = []
         for error in res_errors['devices'] + res_errors['kits']:
             if error['code'] == 'ALREADY_CLAIMED':
                 errors.append(dterrors.ClaimErrorDeviceAlreadyClaimed(error))
@@ -283,5 +294,5 @@ class Claim(dtoutputs.OutputBase):
             # Unpack attributes from raw response dictionary.
             self.kit_id: str = kit['kitId']
             self.display_name: str = kit['displayName']
-            self.devices: List[Claim.ClaimDevice] \
+            self.devices: list[Claim.ClaimDevice] \
                 = [Claim.ClaimDevice(d) for d in kit['devices']]
