@@ -132,7 +132,10 @@ class Emulator():
                       disruptive.events.CellularStatus |
                       disruptive.events.Co2 |
                       disruptive.events.Pressure |
-                      disruptive.events.Motion,
+                      disruptive.events.Motion |
+                      disruptive.events.DeskOccupancy |
+                      disruptive.events.Contact |
+                      disruptive.events.ProbeWireStatus,
                       **kwargs: Any,
                       ) -> None:
         """
